@@ -27,10 +27,11 @@ from stash.serializers.serializer import Serializer
 from stash.serializers.serializer import Serializer
 from stash.serializers.simplejson import SimpleJSONSerializer
 from stash.serializers.ujson import UltraJSONSerializer
-from stash.storages.dbm import DbmStorage
+from stash.storages.dbm_ import DbmStorage
 from stash.storages.filesystem import FileSystemStorage
 from stash.storages.leveldb import LeveldbStorage
 from stash.storages.lmdb import LmdbStorage
+from stash.storages.lsmdb import LsmDbStorage
 from stash.storages.memory import MemoryStorage
 from stash.storages.mongodb import MongoDbStorage
 from stash.storages.null import NullStorage
@@ -71,12 +72,14 @@ __all__: List[str] = [
     "ZstdCodec",
     # storages
     "Storage",
+    "DbmStorage",
     "FileSystemStorage",
     "LmdbStorage",
     "LeveldbStorage",
+    "LsmDbStorage",
     "MemoryStorage",
     "NullStorage",
     "MongoDbStorage",
     "RedisStorage",
-    "DbmStorage",
+    "stash",
 ]
